@@ -1,6 +1,14 @@
 #!/usr/bin/env perl
 
+use 5.018;
+
+use strict;
+use warnings;
+
 use Venus::Random;
 
-# generate 100 random characters
+#
+# Generate 100 random characters
+#
+
 Venus::Random->new->say('collect', 100, 'character');
