@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '3.04';
+our $VERSION = '3.10';
 
 # AUTHORITY
 
@@ -46,7 +46,10 @@ sub import {
     float => 1,
     gather => 1,
     hash => 1,
+    is_false => 1,
+    is_true => 1,
     json => 1,
+    list => 1,
     load => 1,
     log => 1,
     make => 1,
@@ -56,6 +59,7 @@ sub import {
     name => 1,
     number => 1,
     opts => 1,
+    pairs => 1,
     path => 1,
     perl => 1,
     process => 1,
@@ -64,11 +68,13 @@ sub import {
     random => 1,
     regexp => 1,
     replace => 1,
+    render => 1,
     roll => 1,
     search => 1,
     space => 1,
     schema => 1,
     string => 1,
+    syscall => 1,
     template => 1,
     test => 1,
     then => 1,
@@ -94,6 +100,15 @@ sub import {
   return $self;
 }
 
+# HOOKS
+
+sub _qx {
+  my (@args) = @_;
+  local $| = 1;
+  local $SIG{__WARN__} = sub {};
+  (do{local $_ = qx(@{[@args]}); chomp if $_; $_}, $?, ($? >> 8))
+}
+
 # FUNCTIONS
 
 sub args (@) {
@@ -378,6 +393,22 @@ sub hash ($;$@) {
   return Venus::Hash->new($data)->$code(@args);
 }
 
+sub is_false ($) {
+  my ($data) = @_;
+
+  require Venus::Boolean;
+
+  return Venus::Boolean->new($data)->is_false;
+}
+
+sub is_true ($) {
+  my ($data) = @_;
+
+  require Venus::Boolean;
+
+  return Venus::Boolean->new($data)->is_true;
+}
+
 sub json (;$$) {
   my ($code, $data) = @_;
 
@@ -398,6 +429,12 @@ sub json (;$$) {
   return fault(qq(Invalid "json" action "$code"));
 }
 
+sub list (@) {
+  my (@args) = @_;
+
+  return map {defined $_ ? (ref eq 'ARRAY' ? (@{$_}) : ($_)) : ($_)} @args;
+}
+
 sub load ($) {
   my ($data) = @_;
 
@@ -493,6 +530,19 @@ sub opts ($;$@) {
   return Venus::Opts->new($data)->$code(@args);
 }
 
+sub pairs (@) {
+  my ($args) = @_;
+
+  my $result = defined $args
+    ? (
+    ref $args eq 'ARRAY'
+    ? ([map {[$_, $args->[$_]]} 0..$#{$args}])
+    : (ref $args eq 'HASH' ? ([map {[$_, $args->{$_}]} sort keys %{$args}]) : ([])))
+    : [];
+
+  return wantarray ? @{$result} : $result;
+}
+
 sub path ($;$@) {
   my ($data, $code, @args) = @_;
 
@@ -590,6 +640,12 @@ sub regexp ($;$@) {
   return Venus::Regexp->new($data)->$code(@args);
 }
 
+sub render ($;$) {
+  my ($data, $args) = @_;
+
+  return template($data, 'render', undef, $args || {});
+}
+
 sub replace ($;$@) {
   my ($data, $code, @args) = @_;
 
@@ -670,6 +726,41 @@ sub string ($;$@) {
   return Venus::String->new($data)->$code(@args);
 }
 
+sub syscall ($;@) {
+  my (@args) = @_;
+
+  require Venus::Os;
+
+  for (my $i = 0; $i < @args; $i++) {
+    if ($args[$i] =~ /^\|+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^\&+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^\w+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^[<>]+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^\d[<>&]+\d?$/) {
+      next;
+    }
+    if ($args[$i] =~ /\$[A-Z]\w+/) {
+      next;
+    }
+    if ($args[$i] =~ /^\$\((.*)\)$/) {
+      next;
+    }
+    $args[$i] = Venus::Os->quote($args[$i]);
+  }
+
+  my ($data, $exit, $code) = (_qx(@args));
+
+  return wantarray ? ($data, $code) : (($exit == 0) ? true() : false());
+}
+
 sub template ($;$@) {
   my ($data, $code, @args) = @_;
 
@@ -870,7 +961,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-3.04
+3.10
 
 =cut
 
@@ -2238,6 +2329,84 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 is_false
+
+  is_false(Any $data) (Bool)
+
+The is_false function accepts a scalar value and returns true if the value is
+falsy.
+
+I<Since C<3.04>>
+
+=over 4
+
+=item is_false example 1
+
+  package main;
+
+  use Venus 'is_false';
+
+  my $is_false = is_false 0;
+
+  # true
+
+=back
+
+=over 4
+
+=item is_false example 2
+
+  package main;
+
+  use Venus 'is_false';
+
+  my $is_false = is_false 1;
+
+  # false
+
+=back
+
+=cut
+
+=head2 is_true
+
+  is_true(Any $data) (Bool)
+
+The is_true function accepts a scalar value and returns true if the value is
+truthy.
+
+I<Since C<3.04>>
+
+=over 4
+
+=item is_true example 1
+
+  package main;
+
+  use Venus 'is_true';
+
+  my $is_true = is_true 1;
+
+  # true
+
+=back
+
+=over 4
+
+=item is_true example 2
+
+  package main;
+
+  use Venus 'is_true';
+
+  my $is_true = is_true 0;
+
+  # false
+
+=back
+
+=cut
+
 =head2 json
 
   json(Str $call, Any $data) (Any)
@@ -2306,6 +2475,59 @@ I<Since C<2.40>>
 
 =cut
 
+=head2 list
+
+  list(Any @args) (Any)
+
+The list function accepts a list of values and flattens any arrayrefs,
+returning a list of scalars.
+
+I<Since C<3.04>>
+
+=over 4
+
+=item list example 1
+
+  package main;
+
+  use Venus 'list';
+
+  my @list = list 1..4;
+
+  # (1..4)
+
+=back
+
+=over 4
+
+=item list example 2
+
+  package main;
+
+  use Venus 'list';
+
+  my @list = list [1..4];
+
+  # (1..4)
+
+=back
+
+=over 4
+
+=item list example 3
+
+  package main;
+
+  use Venus 'list';
+
+  my @list = list [1..4], 5, [6..10];
+
+  # (1..10)
+
+=back
+
+=cut
+
 =head2 load
 
   load(Any $name) (Space)
@@ -2719,6 +2941,74 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 pairs
+
+  pairs(Any $data) (ArrayRef)
+
+The pairs function accepts an arrayref or hashref and returns an arrayref of
+arrayrefs holding keys (or indices) and values. The function returns an empty
+arrayref for all other values provided. Returns a list in list context.
+
+I<Since C<3.04>>
+
+=over 4
+
+=item pairs example 1
+
+  package main;
+
+  use Venus 'pairs';
+
+  my $pairs = pairs [1..4];
+
+  # [[0,1], [1,2], [2,3], [3,4]]
+
+=back
+
+=over 4
+
+=item pairs example 2
+
+  package main;
+
+  use Venus 'pairs';
+
+  my $pairs = pairs {'a' => 1, 'b' => 2, 'c' => 3, 'd' => 4};
+
+  # [['a',1], ['b',2], ['c',3], ['d',4]]
+
+=back
+
+=over 4
+
+=item pairs example 3
+
+  package main;
+
+  use Venus 'pairs';
+
+  my @pairs = pairs [1..4];
+
+  # ([0,1], [1,2], [2,3], [3,4])
+
+=back
+
+=over 4
+
+=item pairs example 4
+
+  package main;
+
+  use Venus 'pairs';
+
+  my @pairs = pairs {'a' => 1, 'b' => 2, 'c' => 3, 'd' => 4};
+
+  # (['a',1], ['b',2], ['c',3], ['d',4])
+
+=back
+
+=cut
+
 =head2 path
 
   path(Str $value, Str | CodeRef $code, Any @args) (Any)
@@ -3047,6 +3337,33 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 render
+
+  render(Str $data, HashRef $args) (Str)
+
+The render function accepts a string as a template and renders it using
+L<Venus::Template>, and returns the result.
+
+I<Since C<3.04>>
+
+=over 4
+
+=item render example 1
+
+  package main;
+
+  use Venus 'render';
+
+  my $render = render 'hello {{name}}', {
+    name => 'user',
+  };
+
+  # "hello user"
+
+=back
+
+=cut
+
 =head2 replace
 
   replace(ArrayRef $value, Str | CodeRef $code, Any @args) (Any)
@@ -3268,6 +3585,74 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 syscall
+
+  syscall(Int | Str @args) (Any)
+
+The syscall function perlforms system call, i.e. a L<perlfunc/qx> operation,
+and returns C<true> if the command succeeds, otherwise returns C<false>. In
+list context, returns the output of the operation and the exit code.
+
+I<Since C<3.04>>
+
+=over 4
+
+=item syscall example 1
+
+  package main;
+
+  use Venus 'syscall';
+
+  my $syscall = syscall 'perl', '-v';
+
+  # true
+
+=back
+
+=over 4
+
+=item syscall example 2
+
+  package main;
+
+  use Venus 'syscall';
+
+  my $syscall = syscall 'perl', '-z';
+
+  # false
+
+=back
+
+=over 4
+
+=item syscall example 3
+
+  package main;
+
+  use Venus 'syscall';
+
+  my ($data, $code) = syscall 'sun', '--heat-death';
+
+  # ('done', 0)
+
+=back
+
+=over 4
+
+=item syscall example 4
+
+  package main;
+
+  use Venus 'syscall';
+
+  my ($data, $code) = syscall 'earth', '--melt-icecaps';
+
+  # ('', 127)
+
+=back
+
+=cut
+
 =head2 template
 
   template(Str $value, Str | CodeRef $code, Any @args) (Any)
@@ -4177,6 +4562,16 @@ manipulating regexp replacement data.
 
 =over 4
 
+=item venus-run
+
+This library contains a L<Venus::Run> class which provides a base class for
+providing a command execution system for creating CLIs (command-line
+interfaces).
+
+=back
+
+=over 4
+
 =item venus-scalar
 
 This library contains a L<Venus::Scalar> class which provides methods for
@@ -4213,6 +4608,15 @@ manipulating string data.
 
 =over 4
 
+=item venus-task
+
+This library contains a L<Venus::Task> class which provides a base class for
+creating CLIs (command-line interfaces).
+
+=back
+
+=over 4
+
 =item venus-template
 
 This library contains a L<Venus::Template> class which provides a templating
