@@ -13,6 +13,16 @@ require Venus;
 
 our $NAME = __PACKAGE__;
 
+# HOOKS
+
+sub _print {
+  do {local $| = 1; CORE::print(@_, "\n")}
+}
+
+sub _prompt {
+  do {local $\ = ''; local $_ = <STDIN>; chomp; $_}
+}
+
 # METHODS
 
 state $args = {
@@ -117,7 +127,7 @@ Here are examples usages using the example YAML configuration.
 Copyright 2022-2023, Vesion $Venus::VERSION, The Venus "AUTHOR" and "CONTRIBUTORS"
 
 More information on "vns" and/or the "Venus" standard library, visit
-https://p3rl.org/Venus.
+https://p3rl.org/vns.
 EOF
 
 sub footer {
@@ -252,6 +262,8 @@ sub _exec {
 
   return () if !@data;
 
+  $conf = _set_conf($conf);
+
   my %ORIG_ENV = %ENV;
 
   _set_vars($conf);
@@ -260,21 +272,15 @@ sub _exec {
 
   _set_libs($conf);
 
-  my @args = grep defined, _make($conf, shift(@data)), @data;
+  for my $step (_flow($conf, @data)) {
+    my ($prog, @args) = @{$step};
 
-  my $prog = shift @args;
-
-  require Venus::Os;
-
-  @args = map +(/^\w+$/ ? $_ : /^\$[A-Z]\w+$/ ? $_ : Venus::Os->quote($_)), @args;
-
-  return () if !$prog;
-
-  $code->($prog, @args);
+    $code->($prog, @args) if $prog;
+  }
 
   %ENV = %ORIG_ENV;
 
-  return ($prog, @args);
+  return (@data);
 }
 
 sub _find {
@@ -298,6 +304,18 @@ sub _find {
     unshift @data, @item; @item = shift @data;
   }
 
+  @item = (_find_in_flow($seen, $conf, @item));
+
+  if (@item > 1) {
+    unshift @data, @item; @item = shift @data;
+  }
+
+  @item = (_find_in_func($seen, $conf, @item));
+
+  if (@item > 1) {
+    unshift @data, @item; @item = shift @data;
+  }
+
   @item = (_find_in_perl($seen, $conf, @item));
 
   if (@item > 1) {
@@ -316,6 +334,12 @@ sub _find {
     unshift @data, @item; @item = shift @data;
   }
 
+  @item = (_find_in_with($seen, $conf, @item));
+
+  if (@item > 1) {
+    shift @data; unshift @data, @item; @item = shift @data;
+  }
+
   return (@item, @data);
 }
 
@@ -353,6 +377,36 @@ sub _find_in_find {
     : ($item);
 }
 
+sub _find_in_flow {
+  my ($seen, $conf, $item) = @_;
+
+  return $conf->{flow}
+    ? (
+    $conf->{flow}{$item}
+    ? (do {
+      my $value = $conf->{flow}{$item};
+      join ' && ', map +(join(' ', _exec(sub{}, $conf, $_))), @{$value}
+    })
+    : ($item)
+    )
+    : ($item);
+}
+
+sub _find_in_func {
+  my ($seen, $conf, $item) = @_;
+
+  return $conf->{func}
+    ? (
+    $conf->{func}{$item}
+    ? (do {
+      my $value = _vars($conf->{func}{$item});
+      ('perl', '-E', "(do \"$value\")->(\\\@ARGV)")
+    })
+    : ($item)
+    )
+    : ($item);
+}
+
 sub _find_in_perl {
   my ($seen, $conf, $item) = @_;
 
@@ -408,6 +462,22 @@ sub _find_in_vars {
     : ($item);
 }
 
+sub _find_in_with {
+  my ($seen, $conf, $item) = @_;
+
+  return $conf->{with}
+    ? (
+    $conf->{with}{$item}
+    ? (do {
+      $ENV{ECHO} = 0;
+      $ENV{VENUS_FILE} = _vars($conf->{with}{$item});
+      $ENV{VENUS_RUN_NAME} || 'vns';
+    })
+    : ($item)
+    )
+    : ($item);
+}
+
 sub _find_in_seen {
   my ($seen, $conf, $item, $name, $value) = @_;
 
@@ -416,6 +486,24 @@ sub _find_in_seen {
     : (_find($seen, $conf, $value));
 }
 
+sub _flow {
+  my ($conf, @data) = @_;
+
+  return () if !@data;
+
+  my $item = shift @data;
+
+  return $conf->{flow}
+    ? (
+    $conf->{flow}{$item}
+    ? (do {
+     (map _flow($conf, $_, @data), @{$conf->{flow}{$item}});
+    })
+    : (_prep($conf, $item, @data))
+    )
+    : (_prep($conf, $item, @data));
+}
+
 sub _libs {
   my ($conf) = @_;
 
@@ -446,22 +534,61 @@ sub _make {
   return (($path ? $path : $item), @data);
 }
 
+sub _prep {
+  my ($conf, @data) = @_;
+
+  my @args = map _vars($_), grep defined, _make($conf, shift(@data)), @data;
+
+  my $prog = shift @args;
+
+  require Venus::Os;
+
+  for (my $i = 0; $i < @args; $i++) {
+    if ($args[$i] =~ /^\|+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^\&+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^\w+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^[<>]+$/) {
+      next;
+    }
+    if ($args[$i] =~ /^\d[<>&]+\d?$/) {
+      next;
+    }
+    if ($args[$i] =~ /\$[A-Z]\w+/) {
+      next;
+    }
+    if ($args[$i] =~ /^\$\((.*)\)$/) {
+      if ($1) {
+        $args[$i] = "\$(@{[@{_prep($conf, $1)}]})";
+      }
+      next;
+    }
+    $args[$i] = Venus::Os->quote($args[$i]);
+  }
+
+  return [$prog ? ($prog, @args) : ()];
+}
+
 sub _split {
   my ($text) = @_;
 
   return (grep length, ($text // '') =~ /(?x)(?:"([^"]*)"|([^\s]*))\s?/g);
 }
 
-sub _set_path {
+sub _set_conf {
   my ($conf) = @_;
 
-  require Venus::Os;
-  require Venus::Path;
-
-  if (my $path = $conf->{path}) {
-    $ENV{PATH} = join((Venus::Os->is_win ? ';' : ':'),
-      (map Venus::Path->new($_)->absolute, @{$conf->{path}}), $ENV{PATH});
-  }
+  $conf = Venus::merge(Venus::Config->read_file(_vars($_))->value, $conf)
+    for (
+      $conf->{from}
+      ? ((ref $conf->{from} eq 'ARRAY') ? (@{$conf->{from}}) : ($conf->{from}))
+      : ()
+    );
 
   return $conf;
 }
@@ -474,7 +601,21 @@ sub _set_libs {
 
   my %seen;
   $ENV{PERL5LIB} = join((Venus::Os->is_win ? ';' : ':'),
-    (grep !$seen{$_}++, map Venus::Path->new($_)->absolute, _libs($conf)));
+    (grep !$seen{$_}++, map Venus::Path->new(_vars($_))->absolute, _libs($conf)));
+
+  return $conf;
+}
+
+sub _set_path {
+  my ($conf) = @_;
+
+  require Venus::Os;
+  require Venus::Path;
+
+  if (my $path = $conf->{path}) {
+    $ENV{PATH} = join((Venus::Os->is_win ? ';' : ':'),
+      (map Venus::Path->new(_vars($_))->absolute, @{$conf->{path}}), $ENV{PATH});
+  }
 
   return $conf;
 }
@@ -490,9 +631,19 @@ sub _set_vars {
     $ENV{$_} = join(' ', grep defined, _find({}, $conf, $_)) for keys %{$vars};
   }
 
+  if (my $asks = $conf->{asks}) {
+    for my $key (sort keys %{$asks}) {
+      next if defined $ENV{$key}; _print $asks->{$key}; $ENV{$key} = _prompt;
+    }
+  }
+
   return $conf;
 }
 
+sub _vars {
+  (($_[0] // '') =~ s{\$([A-Z]+)}{$ENV{$1}//"\$".$1}egr)
+}
+
 # AUTORUN
 
 run Venus::Run;
@@ -527,139 +678,13 @@ Runner Class for Perl 5
 
 =head1 DESCRIPTION
 
-This package is a L<Venus::Task> which provides generic task running
-capabilities. A simple CLI using this package has been made available in
-L<vns>.
-
-=head1 USAGES
-
-Here is an example configuration file in YAML (e.g. in C<.vns.yaml>).
-
-  ---
-  data:
-    ECHO: true
-  exec:
-    okay: \$PERL -c
-    cpan: cpanm -llocal -qn
-    deps: cpan --installdeps .
-    each: \$PERL -MVenus=log -nE
-    exec: \$PERL -MVenus=log -E
-    repl: \$PERL -dE0
-    says: exec "map log(\$_), map eval, \@ARGV"
-    test: \$PROVE
-  libs:
-  - -Ilib
-  - -Ilocal/lib/perl5
-  load:
-  - -MVenus=true,false
-  path:
-  - ./bin
-  - ./dev
-  - -Ilocal/bin
-  perl:
-    perl: perl
-    prove: prove
-  vars:
-    PERL: perl
-    PROVE: prove
-
-The following describes the configuration file sections and how they're used:
-
-=over 4
-
-=item *
-
-The C<data> section provides a non-dynamic list of key/value pairs that will
-be used as environment variables.
-
-=item *
-
-The C<exec> section provides the main dynamic tasks which can be recursively
-resolved and expanded.
-
-=item *
-
-The C<find> section provides aliases which can be recursively resolved and
-expanded for use in other tasks.
-
-=item *
-
-The C<libs> section provides a list of C<-I/path/to/lib> "include" statements
-that will be automatically added to tasks expanded from the C<perl> section.
-
-=item *
-
-The C<load> section provides a list of C<-MPackage> "import" statements
-that will be automatically added to tasks expanded from the C<perl> section.
-
-=item *
-
-The C<path> section provides a list of paths to be prepended to the C<PATH>
-environment variable which allows programs to be found.
-
-=item *
-
-The C<perl> section provides the dynamic perl tasks which can serve as tasks
-with default commands (with options) and which can be recursively resolved and
-expanded.
-
-=item *
-
-The C<task> section provides the dynamic perl tasks which "load" L<Venus::Task>
-derived packages, and which can be recursively resolved and expanded. These
-tasks will typically take the form of C<perl -Ilib -MMyApp::Task -E0 --> and
-will be automatically executed as a CLI.
-
-=item *
-
-The C<vars> section provides a list of dynamic key/value pairs that can be
-recursively resolved and expanded and will be used as environment variables.
-
-=back
-
-Here are example usages using the example YAML configuration file and the
-L<vns> CLI.
-
-  # Mint a new configuration file
-  vns init
-
-  ...
-
-  # Install a distribution
-  vns cpan $DIST
-
-  i.e. $(which cpanm) --llocal -qn $DIST
-
-  # Install dependencies in the CWD
-  vns deps
-
-  i.e. $(which cpanm) --llocal -qn --installdeps .
-
-  # Check that a package can be compiled
-  vns okay $FILE
-
-  i.e. $(which perl) -Ilib -Ilocal/lib/perl5 -c $FILE
-
-  # Use the Perl debugger as a REPL
-  vns repl
-
-  i.e. $(which perl) -Ilib -Ilocal/lib/perl5 -dE0
-
-  # Evaluate arbitrary Perl expressions
-  vns exec ...
-
-  i.e. $(which perl) -Ilib -Ilocal/lib/perl5 -MVenus=log -E $@
-
-  # Test the Perl project in the CWD
-  vns test t
-
-  i.e. $(which prove) -Ilib -Ilocal/lib/perl5 t
-
-This package and CLI allows you to define task definitions for any application,
-which you can run using the name of the task. You can reuse existing task
-definitions in new tasks which will be recursively resolved when needed. You
-can define static and dynamic environment variables, and also pre-define
-"includes" and the order in which they're declared.
+This package is a subclass of L<Venus::Task> which provides a command execution
+system. This package loads the configuration file used for defining tasks (i.e.
+command-line operations) which can recursively resolve, injects environment
+variables, resets the C<PATH> and C<PERL5LIB> variables where appropriate, and
+executes the tasks by name. See L<vns> for an executable file which loads this
+package and provides the CLI. See L</FEATURES> for usage and configuration
+information.
 
 =cut
 
@@ -1143,6 +1168,14 @@ I<Since C<2.91>>
 
   # on linux
 
+  # in config
+  #
+  # ---
+  # exec:
+  #   cpan: cpanm -llocal -qn
+  #
+  # ...
+
   my $run = Venus::Run->new(['cpan', 'Venus']);
 
   $run->execute;
@@ -1163,6 +1196,15 @@ I<Since C<2.91>>
 
   # on linux
 
+  # in config
+  #
+  # ---
+  # exec:
+  #   cpan: cpanm -llocal -qn
+  #   deps: cpan --installdeps .
+  #
+  # ...
+
   my $run = Venus::Run->new(['deps']);
 
   $run->execute;
@@ -1183,6 +1225,25 @@ I<Since C<2.91>>
 
   # on linux
 
+  # in config
+  #
+  # ---
+  # exec:
+  #   okay: $PERL -c
+  #
+  # ...
+  #
+  # libs:
+  # - -Ilib
+  # - -Ilocal/lib/perl5
+  #
+  # ...
+  #
+  # vars:
+  #   PERL: perl
+  #
+  # ...
+
   my $run = Venus::Run->new(['okay', 'lib/Venus.pm']);
 
   $run->execute;
@@ -1203,6 +1264,25 @@ I<Since C<2.91>>
 
   # on linux
 
+  # in config
+  #
+  # ---
+  # exec:
+  #   repl: $PERL -dE0
+  #
+  # ...
+  #
+  # libs:
+  # - -Ilib
+  # - -Ilocal/lib/perl5
+  #
+  # ...
+  #
+  # vars:
+  #   PERL: perl
+  #
+  # ...
+
   my $run = Venus::Run->new(['repl']);
 
   $run->execute;
@@ -1223,6 +1303,25 @@ I<Since C<2.91>>
 
   # on linux
 
+  # in config
+  #
+  # ---
+  # exec:
+  #   exec: $PERL
+  #
+  # ...
+  #
+  # libs:
+  # - -Ilib
+  # - -Ilocal/lib/perl5
+  #
+  # ...
+  #
+  # vars:
+  #   PERL: perl
+  #
+  # ...
+
   my $run = Venus::Run->new(['exec', '-MVenus=date', 'say date']);
 
   $run->execute;
@@ -1243,6 +1342,25 @@ I<Since C<2.91>>
 
   # on linux
 
+  # in config
+  #
+  # ---
+  # exec:
+  #   test: $PROVE
+  #
+  # ...
+  #
+  # libs:
+  # - -Ilib
+  # - -Ilocal/lib/perl5
+  #
+  # ...
+  #
+  # vars:
+  #   PROVE: prove
+  #
+  # ...
+
   my $run = Venus::Run->new(['test', 't']);
 
   $run->execute;
@@ -1253,6 +1371,280 @@ I<Since C<2.91>>
 
 =back
 
+=over 4
+
+=item handler example 12
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  my $run = Venus::Run->new(['echo', 1, '|', 'less']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. echo 1 | less
+
+=back
+
+=over 4
+
+=item handler example 13
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  my $run = Venus::Run->new(['echo', 1, '&&', 'echo', 2]);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. echo 1 && echo 2
+
+=back
+
+=over 4
+
+=item handler example 14
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  local $ENV{VENUS_FILE} = 't/conf/from.perl';
+
+  # in config
+  #
+  # ---
+  # from:
+  # - /path/to/parent
+  #
+  # ...
+  #
+  # exec:
+  #   mypan: cpan -M https://pkg.myapp.com
+
+  # in config (/path/to/parent)
+  #
+  # ---
+  # exec:
+  #   cpan: cpanm -llocal -qn
+  #
+  # ...
+
+  my $run = Venus::Run->new(['mypan']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. cpanm '-llocal' '-qn' '-M' 'https://pkg.myapp.com'
+
+=back
+
+=over 4
+
+=item handler example 15
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  local $ENV{VENUS_FILE} = 't/conf/with.perl';
+
+  # in config
+  #
+  # ---
+  # with:
+  #   psql: /path/to/other
+  #
+  # ...
+
+  # in config (/path/to/other)
+  #
+  # ---
+  # exec:
+  #   backup: pg_backupcluster
+  #   restore: pg_restorecluster
+  #
+  # ...
+
+  my $run = Venus::Run->new(['psql', 'backup']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. vns backup
+
+=back
+
+=over 4
+
+=item handler example 16
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  local $ENV{VENUS_FILE} = 't/conf/with.perl';
+
+  # in config
+  #
+  # ---
+  # with:
+  #   psql: /path/to/other
+  #
+  # ...
+
+  # in config (/path/to/other)
+  #
+  # ---
+  # exec:
+  #   backup: pg_backupcluster
+  #   restore: pg_restorecluster
+  #
+  # ...
+
+  my $run = Venus::Run->new(['psql', 'backup']);
+
+  $run->execute;
+
+  # VENUS_FILE=t/conf/psql.perl vns backup
+
+  local $ENV{VENUS_FILE} = 't/conf/psql.perl';
+
+  $run = Venus::Run->new(['backup']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. pg_backupcluster
+
+=back
+
+=over 4
+
+=item handler example 17
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  # in config
+  #
+  # ---
+  # exec:
+  #   cpan: cpanm -llocal -qn
+  #
+  # ...
+  #
+  # flow:
+  #   setup-term:
+  #   - cpan Term::ReadKey
+  #   - cpan Term::ReadLine::Gnu
+  #
+  # ...
+
+  local $ENV{VENUS_FILE} = 't/conf/flow.perl';
+
+  my $run = Venus::Run->new(['setup-term']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e.
+  # cpanm '-llocal' '-qn' 'Term::ReadKey'
+  # cpanm '-llocal' '-qn' 'Term::ReadLine::Gnu'
+
+=back
+
+=over 4
+
+=item handler example 18
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  # in config
+  #
+  # ---
+  # asks:
+  #   PASS: What's the password
+  #
+  # ...
+
+  local $ENV{VENUS_FILE} = 't/conf/asks.perl';
+
+  my $run = Venus::Run->new(['echo', '$PASS']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. echo '$PASS'
+
+=back
+
+=over 4
+
+=item handler example 19
+
+  package main;
+
+  use Venus::Run;
+
+  # on linux
+
+  # in config
+  #
+  # ---
+  # func:
+  #   dump: /path/to/dump.pl
+  #
+  # ...
+
+  # in dump.pl (/path/to/dump.pl)
+  #
+  # sub {
+  #   my ($args) = @_;
+  #
+  #   ...
+  # }
+
+  local $ENV{VENUS_FILE} = 't/conf/func.perl';
+
+  my $run = Venus::Run->new(['dump', '--', 'hello']);
+
+  $run->execute;
+
+  # ()
+
+  # i.e. perl -Ilib ... -E '(do "./t/path/etc/dump.pl")->(\@ARGV)' '--' hello
+
+=back
+
 =cut
 
 =head2 init
@@ -1408,6 +1800,305 @@ I<Since C<2.91>>
 
 =cut
 
+=head1 FEATURES
+
+This package provides the following features:
+
+=cut
+
+=over 4
+
+=item config
+
+The CLI provided by this package operates on a configuration file, typically
+having a base name of C<.vns> with a Perl, JSON, or YAML file extension. Here
+is an example of a configuration file using YAML with the filename
+C<.vns.yaml>.
+
+  ---
+  data:
+    ECHO: true
+  exec:
+    okay: $PERL -c
+    cpan: cpanm -llocal -qn
+    deps: cpan --installdeps .
+    each: $PERL -MVenus=log -nE
+    exec: $PERL -MVenus=log -E
+    repl: $PERL -dE0
+    says: exec "map log(\$_), map eval, \@ARGV"
+    test: $PROVE
+  libs:
+  - -Ilib
+  - -Ilocal/lib/perl5
+  load:
+  - -MVenus=true,false
+  path:
+  - ./bin
+  - ./dev
+  - -Ilocal/bin
+  perl:
+    perl: perl
+    prove: prove
+  vars:
+    PERL: perl
+    PROVE: prove
+
+=back
+
+=over 4
+
+=item config-asks
+
+  ---
+  asks:
+    HOME: Enter your home dir
+
+The configuration file's C<asks> section provides a list of key/value pairs
+where the key is the name of the environment variable and the value is used as
+the message used by the CLI to prompt for input if the environment variable is
+not defined.
+
+=back
+
+=over 4
+
+=item config-data
+
+  ---
+  data:
+    ECHO: true
+
+The configuration file's C<data> section provides a non-dynamic list of
+key/value pairs that will be used as environment variables.
+
+=back
+
+=over 4
+
+=item config-exec
+
+  ---
+  exec:
+    okay: $PERL -c
+
+The configuration file's C<exec> section provides the main dynamic tasks which
+can be recursively resolved and expanded.
+
+=back
+
+=over 4
+
+=item config-find
+
+  ---
+  find:
+    cpanm: /usr/local/bin/cpanm
+
+The configuration file's C<find> section provides aliases which can be
+recursively resolved and expanded for use in other tasks.
+
+=back
+
+=over 4
+
+=item config-flow
+
+  ---
+  flow:
+    deps:
+    - cpan Term::ReadKey
+    - cpan Term::ReadLine::Gnu
+
+The configuration file's C<flow> section provides chainable tasks which are
+recursively resolved and expanded from other tasks.
+
+=back
+
+=over 4
+
+=item config-from
+
+  ---
+  from:
+  - /usr/share/vns/.vns.yaml
+
+The configuration file's C<from> section provides paths to other configuration
+files which will be merged before execution allowing the inheritance of of
+configuration values.
+
+=back
+
+=over 4
+
+=item config-func
+
+  ---
+  func:
+    build: ./scripts/build.pl
+
+The configuration file's C<func> section provides a list of static key/value
+pairs where the key is the "subcommand" passed to the runner as the first
+arugment, and the value is the Perl script that will be loaded and executed.
+The Perl script is expected to return a subroutine reference and will be passed
+an array reference to the arguments provided.
+
+=back
+
+=over 4
+
+=item config-libs
+
+  ---
+  libs:
+  - -Ilib
+  - -Ilocal/lib/perl5
+
+The configuration file's C<libs> section provides a list of C<-I/path/to/lib>
+"include" statements that will be automatically added to tasks expanded from
+the C<perl> section.
+
+=back
+
+=over 4
+
+=item config-load
+
+  ---
+  load:
+  - -MVenus=true,false
+
+The configuration file's C<load> section provides a list of C<-MPackage>
+"import" statements that will be automatically added to tasks expanded from the
+C<perl> section.
+
+=back
+
+=over 4
+
+=item config-path
+
+  ---
+  path:
+  - ./bin
+  - ./dev
+  - -Ilocal/bin
+
+The configuration file's C<path> section provides a list of paths to be
+prepended to the C<PATH> environment variable which allows programs to be
+found.
+
+=back
+
+=over 4
+
+=item config-perl
+
+  ---
+  perl:
+    perl: perl
+
+The configuration file's C<perl> section provides the dynamic perl tasks which
+can serve as tasks with default commands (with options) and which can be
+recursively resolved and expanded.
+
+=back
+
+=over 4
+
+=item config-task
+
+  ---
+  task:
+    setup: $PERL -MMyApp::Task::Setup -E0 --
+
+The configuration file's C<task> section provides the dynamic perl tasks which
+"load" L<Venus::Task> derived packages, and which can be recursively resolved
+and expanded. These tasks will typically take the form of C<perl -Ilib
+-MMyApp::Task -E0 --> and will be automatically executed as a CLI.
+
+=back
+
+=over 4
+
+=item config-vars
+
+  ---
+  vars:
+    PERL: perl
+
+The configuration file's C<vars> section provides a list of dynamic key/value
+pairs that can be recursively resolved and expanded and will be used as
+environment variables.
+
+=back
+
+=over 4
+
+=item config-with
+
+  ---
+  with:
+    psql: ./psql-tools/.vns.yml
+
+The configuration file's C<with> section provides a list of static key/value
+pairs where the key is the "subcommand" passed to the runner as the first
+arugment, and the value is the configuration file where the subcommand task
+definitions are defined which the runner dispatches to.
+
+=back
+
+=over 4
+
+=item vns-cli
+
+Here are example usages of the configuration file mentioned, executed by the
+L<vns> CLI, which is simply an executable file which loads this package.
+
+  # Mint a new configuration file
+  vns init
+
+  ...
+
+  # Mint a new JSON configuration file
+  VENUS_FILE=.vns.json vns init
+
+  # Mint a new YAML configuration file
+  VENUS_FILE=.vns.yaml vns init
+
+  ...
+
+  # Install a distribution
+  vns cpan $DIST
+
+  i.e. cpanm --llocal -qn $DIST
+
+  # Install dependencies in the CWD
+  vns deps
+
+  i.e. cpanm --llocal -qn --installdeps .
+
+  # Check that a package can be compiled
+  vns okay $FILE
+
+  i.e. perl -Ilib -Ilocal/lib/perl5 -c $FILE
+
+  # Use the Perl debugger as a REPL
+  vns repl
+
+  i.e. perl -Ilib -Ilocal/lib/perl5 -dE0
+
+  # Evaluate arbitrary Perl expressions
+  vns exec ...
+
+  i.e. perl -Ilib -Ilocal/lib/perl5 -MVenus=log -E $@
+
+  # Test the Perl project in the CWD
+  vns test t
+
+  i.e. prove -Ilib -Ilocal/lib/perl5 t
+
+=back
+
 =head1 AUTHORS
 
 Awncorp, C<awncorp@cpan.org>
