@@ -240,7 +240,7 @@ sub run {
 
   my $CAN_RUN = not(caller(1)) || scalar(caller(1)) eq 'main';
 
-  $self->class->new(@args)->execute if $ENV{VENUS_TASK_RUN} && $CAN_RUN;
+  $self->class->new(@args)->maybe('execute') if $ENV{VENUS_TASK_RUN} && $CAN_RUN;
 
   return $self;
 }
@@ -458,7 +458,7 @@ I<Since C<2.91>>
 
 The cmds method can be overridden and returns a hashref suitable to be passed
 to the L<Venus::Cli/set> method as type C<"cmd">. A C<"cmd"> is a CLI command
-which maps to an positional argument declare by L</arg>.
+which maps to an positional argument declare by L</args>.
 
 I<Since C<2.91>>
 
@@ -946,9 +946,9 @@ I<Since C<2.91>>
 
   help() (Str)
 
-The help method can be overridden and returns the result of L<Venus::Cli/help>.
-This method is returns the default help text based on the configuration of the
-L</cli> object.
+The help method can be overridden and returns a string representing "help" text
+for the CLI. By default this method returns the result of L<Venus::Cli/help>,
+based on the L</cli> object.
 
 I<Since C<2.91>>
 
@@ -1173,7 +1173,7 @@ I<Since C<2.91>>
   name() (Task)
 
 The name method can be overridden and returns the name of the task (and
-application). This method is default to C<$0> if not overridden.
+application). This method defaults to C<$0> if not overridden.
 
 I<Since C<2.91>>
 
